@@ -2,10 +2,12 @@
 
 import collections
 import collections.abc
+import importlib.metadata
 import itertools
 import os
 import re
 import shutil
+import sys
 import typing
 
 import click
@@ -13,6 +15,7 @@ import click
 import pybibs
 
 from . import models
+from typing import Optional
 
 BIBO_DATABASE_ENV_VAR = "BIBO_DATABASE"
 _ANSI_BOLD = "\033[1m"
@@ -223,7 +226,7 @@ def highlight_text(text: str, highlight: str) -> str:
 
 
 def highlight_match(
-    text: str, result: models.SearchResult, extra_match_info: dict = None
+    text: str, result: models.SearchResult, extra_match_info: Optional[dict] = None
 ) -> typing.Tuple[str, dict]:
     """
     Highlight `text` with `result.match` info. Every bit of info that is in
@@ -252,3 +255,15 @@ def highlight_match(
                     extra_match_val = highlight_text(extra_match_val, val)
                     extra_match_info[key] = extra_match_val
     return text, extra_match_info
+
+
+def get_plugins():
+    """
+    Return a list of EntryPoint objects for group "bibo.plugins".
+    """
+    group = "bibo.plugins"
+    eps = importlib.metadata.entry_points()
+    if sys.version_info >= (3, 12):
+        return eps.select(group=group)
+    else:
+        return eps.get(group, [])
